package fragment;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ProgressBar;

import com.akamai.captioning.CaptionComponent;
import com.akamai.captioning.CaptioningWrapper;
import com.akamai.captioning.ampcaptioningsample.MainActivity;
import com.akamai.captioning.ampcaptioningsample.R;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class EIAFragment extends android.support.v4.app.Fragment
        implements View.OnTouchListener, IPlayerEventsListener {

    private final static String TAG = "AMP-CC-CEA608";
    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/worldnow/608/master.m3u8";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar mProgressBar;


    private CaptionComponent captionComponent; // Captioning plugin
    private CaptioningWrapper captioningWrapper;  // The wrapper is used only for CEA-608


    public static EIAFragment newInstance() {
        EIAFragment fragment = new EIAFragment();
        return fragment;
    }

    public EIAFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.fragment_main, container, false);
        mProgressBar = (ProgressBar) rootView.findViewById(R.id.progressBar);

        captionComponent = (CaptionComponent) rootView.findViewById(R.id.captionView);

        mVideoContainer = (VideoPlayerContainer) rootView.findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                videoPlayerView = mVideoContainer.getVideoPlayer();
                videoPlayerView.setProgressBarControl(mProgressBar);
                videoPlayerView.setLicense(MainActivity.LICENSE);
                videoPlayerView.setFullScreen(true);
                videoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                videoPlayerView.setLogEnabled(true);

                //Generate captions after configure the AMP player
                createCaptions();

                videoPlayerView.addEventsListener(EIAFragment.this);
                videoPlayerView.setKeepScreenOn(true);
                videoPlayerView.setOnTouchListener(EIAFragment.this);

                videoPlayerView.play(mediaResource);
            }

            @Override
            public void onResourceError() {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);

        return rootView;
    }

    /**
     * Caption configuration
     */
    private void createCaptions(){
        captioningWrapper = new CaptioningWrapper(captionComponent);
        captioningWrapper.setVideoPlayerView(videoPlayerView);
        captionComponent.setVideoPlayerView(videoPlayerView);

        captionComponent.setCaptionTextStyle(CaptionComponent.CAPTION_TEXT_NORMAL_STYLE);
        captionComponent.setTextSize(18);
        captionComponent.setTextBackgroundColor(Color.BLACK);
        captionComponent.setTextColor(Color.WHITE);
        //captionComponent.setTextWindowColor(Color.CYAN);
        //captionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_ROLL_UP);

        //Typeface tf = Typeface.createFromAsset(this.getAssets(), "fonts/Arial Black.ttf");
        //captionComponent.setTypeface(tf);
    }

    @Override
    public void onResume() {
        Log.d(TAG, "OnResume");
        if (videoPlayerView != null) {
            videoPlayerView.resume();
        }
        super.onResume();
    }

    @Override
    public void onPause() {
        Log.d(TAG, "OnPause");
        if(videoPlayerView != null){
            videoPlayerView.pause();
        }
        super.onPause();
    }

    @Override
    public void onDestroy() {
        Log.d(TAG, "OnDestroy");
        if (videoPlayerView!=null) {
            videoPlayerView.stop();
            videoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d(TAG, "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }
}

